@@ -1,6 +1,5 @@
 import logging
 import numpy as np
-from scipy.ndimage import zoom
 from numbers import Number
 
 
@@ -140,6 +139,8 @@ class RSImage(object):
         :param order: interpolation order, integer
         :return: data as desired
         """
+        from scipy.ndimage import zoom  # import here to avoid static TLS ImportError
+
         assert self.target_resolution is None
 
         if target_resolution is None:
@@ -166,8 +167,9 @@ class RSImage(object):
 
     def image_to_rgb(self, rgb_bands=("B11", "B08", "B03"), rgb_gamma=(1.0, 1.0, 1.0), hist_chop_off_fraction=0.01,
                      output_size=None, max_hist_pixel=1000 ** 2, resample_order=3):
-        # importing skimage here avoids ImportError: dlopen: cannot load any more object with static TLS
+        # importing skimage and scipy here avoids ImportError: dlopen: cannot load any more object with static TLS
         from skimage.exposure import rescale_intensity, adjust_gamma
+        from scipy.ndimage import zoom
 
         if output_size is None:
             if self.target_resolution is None:
