@@ -18,8 +18,6 @@ import numpy as np
 from dicttoxml import dicttoxml
 import matplotlib.pyplot as plt
 from mpl_toolkits.axes_grid1 import make_axes_locatable
-from scipy.interpolate import griddata
-from scipy.ndimage import zoom, gaussian_filter
 from datetime import datetime, timedelta
 
 from .Tools import inpaint, fl, cl, itt2d, nanmean_filter
@@ -198,6 +196,7 @@ def include_missing_spatial_samplings(data, samplings, order=0, base_key=None):
     :param base_key: if None, first key:value pairs in data is used, otherwise this one
     :return:
     """
+    from scipy.ndimage import zoom  # import here avoids static TLS ImportError
 
     if base_key is None:
         base_spatial_sampling = list(data.keys())[0]
@@ -291,6 +290,8 @@ def wv(fo, s2img, clear_areas, s2spr, s2tau, nanmean, sigma, rho_bounds,
     :param logger: None or logging instance
     :returns: Retrieved water vapor map.
     """
+    from scipy.interpolate import griddata  # import here avoids static TLS ImportError
+
     logger = logger or logging.getLogger(__name__)
     # prep data
     data = s2img.image_subsample(channels=bands,
@@ -424,6 +425,8 @@ def wv_band_ratio(fo, s2img, clear_areas, s2spr, nanmean, sigma,
 
 def nan_gaussian_filter(data, sigma):
     """A gaussian filter that works on array with NaN values."""
+    from scipy.ndimage import gaussian_filter  # import here avoids static TLS ImportError
+
     vv = data.copy()
     vv[data != data] = 0
     vv_g = gaussian_filter(vv, sigma=sigma)
@@ -553,6 +556,8 @@ def prepare_s2_ac(s2spr, s2cwv, s2tau, clear_areas,
 def ac_interpolation(iband, band, s2img, s2spr, s2cwv, s2tau, clear_areas, points, rhos, rfls, max_pixel_processing,
                      reduce_lut=True):
     """Atmospheric correction based on interpolation in unstructured grid."""
+    from scipy.interpolate import griddata  # import here avoids static TLS ImportError
+
     ss = s2img.band_spatial_sampling[band]
     points[:, -1] = rfls[:, iband]
 
